@@ -679,6 +679,7 @@ class SensorEvent(RFXtrxEvent):
                 self.values['Contract type'] = pkt.contract_type
         if isinstance(pkt, lowlevel.Security1):
             self.values['Sensor Status'] = pkt.security1_status_string
+            self.values['Tamper'] = pkt.tamper
         if not isinstance(pkt, (lowlevel.Energy5,
                                 lowlevel.RfxMeter,
                                 lowlevel.Undecoded)):
@@ -874,7 +875,8 @@ def transport_errors(message):
                 return func(instance, *args, **kargs)
             except (socket.error,
                     serial.SerialException,
-                    OSError) as exception:
+                    OSError,
+                    TypeError) as exception:
                 _LOGGER.debug("%s failed: %s", message,
                               str(exception), exc_info=True)
                 raise RFXtrxTransportError(
